<?php

// Register quick start pages
if (is_admin()) {
	function displetretsidx_check_if_need_to_create_quick_start_pages () {
		// Get options from settings page
		$displetretsidx_option = get_option('displet_rets_idx_options');

		// Create quick start if Criteria entered
		if (!empty($displetretsidx_option['quick_start_criteria'])) {
			DispletRetsIdxQuickStart::create();
		}
	}
	add_action('init', 'displetretsidx_check_if_need_to_create_quick_start_pages');
}

class DispletRetsIdxQuickStart{
	public function create(){
		// Get options from settings page
		$displetretsidx_option = DispletRetsIdxSettings::get_option();

		// Decide slug from Type selected
		if ($displetretsidx_option['quick_start_type'] == 'city'){
			$name = 'Cities';
			$slug = 'cities';
		}
		else if ($displetretsidx_option['quick_start_type'] == 'zip'){
			$name = 'Zip Codes';
			$slug = 'zip-codes';
		}
		else if ($displetretsidx_option['quick_start_type'] == 'subdivision'){
			$name = 'Subdivisions';
			$slug = 'subdivisions';
		}
		else if ($displetretsidx_option['quick_start_type'] == 'school_district'){
			$name = 'School Districts';
			$slug = 'school-districts';
		}
		else if ($displetretsidx_option['quick_start_type'] == 'school'){
			$name = 'Schools';
			$slug = 'schools';
		}

		// Create menu if needed
		if ($displetretsidx_option['quick_start_parent_menu'] == 'new') {
			$menu_id = self::register_menu($name);
		}
		// Get ID of selected menu
		else if (!empty($displetretsidx_option['quick_start_parent_menu']) && $displetretsidx_option['quick_start_parent_menu'] != 'none') {
			$menu_id = $displetretsidx_option['quick_start_parent_menu'];
		}
		// Menu not set or set to none
		else{
			$menu_id = false;
		}

		// Create parent page if needed
		if ($displetretsidx_option['quick_start_parent_page'] == 'new') {
			$parent_id = self::register_parent_page($name, $slug);
		}
		// Get ID of selected parent page
		else if (!empty($displetretsidx_option['quick_start_parent_page']) && $displetretsidx_option['quick_start_parent_page'] != 'none') {
			$parent_id = $displetretsidx_option['quick_start_parent_page'];
		}
		// Parent page not set or set to none
		else{
			$parent_id = false;
		}

		// Create pages for each
		$criteria_values = explode("\n", $displetretsidx_option['quick_start_criteria']);
		if (!empty($criteria_values)){
			self::register_pages($criteria_values, $displetretsidx_option['quick_start_type'], $menu_id, $parent_id);
		}

		// Remove Criteria to prevent looping creation
		$displetretsidx_option['quick_start_criteria'] = '';
		update_option('displet_rets_idx_options', $displetretsidx_option);
	}

	private function register_pages($criteria_values, $criteria_type, $menu_id, $parent_id){
		foreach ($criteria_values as $value) {
			$value = trim($value);
			if (!empty($parent_id)){
				$parent_path = str_replace(site_url(), '', get_permalink($parent_id));
				$path = $parent_path . $value;
			}
			else{
				$path = $value;
			}
			$post = get_page_by_path($path . '-real-estate');

			// Add page if it doesn't exist
			if (!$post) {
				$quick_start_args = array(
					'post_name' => $value . '-real-estate',
					'post_title' => $value . ' Real Estate',
					'post_content' => '[DispletListing ' . $criteria_type . '="' . $value . '"]',
					'post_type' => 'page',
					'post_status' => 'publish'
				);
				if (!empty($parent_id)){
					$quick_start_args['post_parent'] = $parent_id;
				}
				$post_id = wp_insert_post($quick_start_args);
			}

			// Remove page from the trash if it already exists
			else{
				$quick_start_args = array(
					'post_status' => 'publish',
					'ID' => $post->ID
				);
				wp_update_post($quick_start_args);
				$post_id = $post->ID;
			}

			// Add to menu if ID is set
			if (!empty($menu_id)){
    			wp_update_nav_menu_item($menu_id, 0, array(
					'menu-item-object' => 'page',
					'menu-item-object-id' => $post_id,
					'menu-item-title' => $value,
					'menu-item-type' => 'post_type',
					'menu-item-status' => 'publish'
    			));
			}
		}
	}

	private function register_parent_page($name, $slug){
		$value = trim($value);
		$post = get_page_by_path($slug);
		// Add page if it doesn't exist
		if (!$post) {
			$quick_start_args = array(
				'post_name' => $slug,
				'post_title' => $name,
				'post_type' => 'page',
				'post_status' => 'publish'
			);
			$post_id = wp_insert_post($quick_start_args);
		}
		// Remove page from the trash if it already exists
		else{
			$quick_start_args = array(
				'post_status' => 'publish',
				'ID' => $post->ID
			);
			wp_update_post($quick_start_args);
			$post_id = $post->ID;
		}
		return $post_id;
	}

	private function register_menu($name){
		$menu = wp_get_nav_menu_object($name);
		if (!$menu){
			$menu_id = wp_create_nav_menu($name);
		}
		else{
			$menu_id = $menu->term_id;
		}
		return $menu_id;
	}
}

?>